<template>
  <section
    v-show="warehouse.shop_color == 1 || warehouse.shop_color == 2"
    :class="{ ['color' + warehouse.shop_color]: true, ['layout' + warehouse.shop_style]: true }"
    class="warehouse">
    <div class="shop-html">
      <div class="shop-body">
        <div
          v-show="warehouse.shop_style == 2"
          class="yat">
          <div id="yatlogo">
            <img
              id="yatlogoimg"
              :src="logo"
              width="98"
              height="81">
          </div>
        </div>
        <div id="warehouselights">
          <div
            v-if="warehouse.admin"
            id="menubg">
            <div id="menu">
              <ul
                id="nav"
                class="tab-buttons">
                <router-link
                  :to="{name: 'warehousemain'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'warehousemain')}"
                    class="tab">Home
                  </a>
                </router-link>
                <router-link
                  :to="{name: 'warehouseprice'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'warehouseprice')}"
                    class="tab">Edit Price
                  </a>
                </router-link>
                <router-link
                  :to="{name: 'warehouseorders'}"
                  tag="li">
                  <a
                    id="pickup-orders-tab"
                    :class="{selected: (this.$route.name === 'warehouseorders')}"
                    class="tab">Orders
                  </a>
                </router-link>
                <router-link
                  :to="{name: 'warehouseaccounting'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'warehouseaccounting')}"
                    class="tab">Accounting
                  </a>
                </router-link>
                <div class="clear"/>
              </ul>
            </div>
          </div>
          <div class="headerwidthcontainer">
            <div
              v-show="warehouse.shop_style == 1"
              id="yatlogo">
              <img
                id="yatlogoimg"
                :src="logo"
                width="98"
                height="81">
            </div>
            <div id="shopname">{{ warehouse.name }}</div>
            <div
              v-show="warehouse.shop_style == 2"
              id="shopdesc">{{ warehouse.description }}
            </div>
          </div>
          <div class="contentwidthcontainer">
            <div id="sidebar">
              <div v-if="warehouse.shop_style == 1">
                <product-stock :products="products" />
                <div class="shelf"/>
                <div v-if="warehouse.admin">
                  <order-notifications
                    :shop="warehouse.canonical_name"
                    :show="showOrderNotification" />
                  <div class="shelf"/>
                </div>
              </div>
              <div v-else-if="warehouse.shop_style == 2">
                <div v-if="warehouse.admin">
                  <order-notifications
                    :shop="warehouse.canonical_name"
                    :show="showOrderNotification" />
                  <div class="shelf"/>
                </div>
                <product-stock :products="products" />
                <div class="shelf"/>
              </div>
              <div
                v-if="warehouse.admin"
                id="recent-sales"
                class="widget tub">
                <h1>Recent Sales</h1>
                <recent-sales :shop="warehouse" />
              </div>
              <div class="widget">
                <headlines />
              </div>
              <div
                v-show="warehouse.shop_style == 1"
                class="shelf"/>
              <div class="widget">
                <action-buttons
                  v-if="Object.keys(warehouse).length"
                  :has-swiper="hasSwiper"
                  :shop="warehouse" />
              </div>
              <div
                v-show="warehouse.shop_style == 1"
                class="shelf" />
            </div>
            <div id="mainpagecontent">
              <router-view
                :shop="warehouse"
                :orders="orders"
                :products="products"
                :prices="prices"
                @simple-one="simpleOne"
                @simple-two="simpleTwo"
                @busy-one="busyOne"
                @busy-two="busyTwo"
                @product-changed="getProducts"
                @price-changed="getPrices" />
            </div>
            <div class="clear"/>
          </div>
        </div>
      </div>
    </div>
  </section>
</template>

<script>
import ShopBaseView from "../shopBase.js";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";
import OrderNotifications from "../../../../shared/views/shopTransactions/OrderNotification.vue";
import ProductStock from "../../../../shared/views/shopTransactions/ProductStock.vue";
import RecentSales from "../RecentSales.vue";

export default {
  components: {
    Headlines,
    ActionButtons,
    OrderNotifications,
    ProductStock,
    RecentSales
  },
  extends: ShopBaseView,
  data() {
    return {
      logo: app.network.data.shop_logo,
      warehouse: {},
      hasSwiper: app.computerSettings.swiper,
      orders: [],
      products: [],
      prices: [],
      intervalID: "",
      showOrderNotification:false,
      // this tracks when to show a notification
      orderAmount:null
    };
  },
  watch: {
    // this is to handle notifications that could come in while on the order view, and to dismiss the view
    "$route" (to, from) {
      if(to.name === "warehouseorders"){
        this.showOrderNotification = false;
      }
      if(from.name === "warehouseorders"){
        this.orderAmount = this.orders.length;
      }
    }
  },
  created: function () {
    let self = this;
    this.getData();
    this.getOrders();
    this.getProducts();
    this.getPrices();
    this.intervalID = setInterval( function(){
      self.getOrders();
      self.getPrices();
      self.getProducts();
    }, 10000);
  },
  destroyed: function () {
    clearInterval(this.intervalID);
  },
  beforeMount: function () {
    this.$router.push({name: "warehousemain"});
  },

  methods: {
    getData() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/warehouse/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.warehouse = Response;
            app.Message( "Found warehouse shop!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    simpleOne() {
      this.warehouse.shop_style = 1;
      this.warehouse.shop_color = 1;
    },
    simpleTwo() {
      this.warehouse.shop_style = 1;
      this.warehouse.shop_color = 2;
    },
    busyOne() {
      this.warehouse.shop_style = 2;
      this.warehouse.shop_color = 1;
    },
    busyTwo() {
      this.warehouse.shop_style = 2;
      this.warehouse.shop_color = 2;
    },
    getProducts(){
      if (app.network.data.name !== "YAT 10") {
        return app.api.Get("/products/?type=dogtag")
          .then( Response => {
            this.products = Response.map(product => {product.price = product.price.toFixed(2); return product;});
          })
        .catch( x => app.Message( x.error, "error" ) );
      }
      //YAT 10 gets briefcases
      app.api.Get("/products/?type=briefcase")
                .then( Response => {
                  this.products = Response.map(product => {product.price = product.price.toFixed(2); return product;});
                })
              .catch( x => app.Message( x.error, "error" ) );
    },
    getPrices(){
      if (app.network.data.name !== "YAT 10") {
        return app.api.Get("/prices/?type=dogtag")
        .then( Response => {
          this.prices = Response;
        })
        .catch( x => app.Message( x.error, "error" ) );
      }
      app.api.Get("/prices/?type=briefcase")
      .then( Response => {
        this.prices = Response;
      })
      .catch( x => app.Message( x.error, "error" ) );
    },
    getOrders(){
      if (app.network.data.name !== "YAT 10") {
        return app.api.Get( "/orders/bytype/?type=dogtag")
          .then( Response => {
            this.orders = Response;
            // this is to handle the initial showing of the order notification, and handle updates
            if(this.orderAmount === null){
              this.orderAmount = this.orders.length;
            }
            if(this.$route.name !== "warehouseorders"){
              if(this.orders.length > this.orderAmount){
                this.orderAmount = this.orders.length;
                this.showOrderNotification = true;
              }
            }
          })
        .catch( x => app.Message( x.error, "error" ) );
      }
      app.api.Get( "/orders/bytype/?type=briefcase")
        .then( Response => {
          this.orders = Response;
          // this is to handle the initial showing of the order notification, and handle updates
          if(this.orderAmount === null){
            this.orderAmount = this.orders.length;
          }
          if(this.$route.name !== "warehouseorders"){
            if(this.orders.length > this.orderAmount){
              this.orderAmount = this.orders.length;
              this.showOrderNotification = true;
            }
          }
        })
      .catch( x => app.Message( x.error, "error" ) );
    }
  },

};
</script>

<style lang="less">
.warehouse.layout1.color1 {
  /* Warehouse common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/warehouse/containerbg.jpg);
  @tabactivefontcolor: #fff;


  @maincontentcolor: #ffffff;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }

  .fullback() {
    background-image: @bgimage;
    background-repeat:repeat;
    background-position:center 0rem;
    background-size:30rem 30rem;
    height:45.9rem;
  }
  /* Warehouse color 1 */
  @shoptitlecolor: #aced15;
  @logoborder: 0.5rem solid #aced15;
  @shopdesccolor:#fff;
  @homemsgcolor:#144a68;
  @hometxtcolor:#008e18;
  @welcomecolor: white;
  @welcomeshadow: -.1rem -.1rem 0 rgba(0,0,0,.4);
  @shopbackgroundcolor:#fccb42;
  @bgimage: url(/images/shop/warehouse/warehousebg.jpg);
  @tabfontcolor: #aced15;
  @lightsbg: url(/images/shop/warehouse/warehouse-lights.png);
  .bggradient() {
    background: -moz-linear-gradient(top,  rgba(255,255,255,.3) 10%, rgba(255,255,255,.1) 30%, rgba(255,255,255,0) 100%);
    background: linear-gradient(to bottom,  rgba(255,255,255,.3) 10%,rgba(255,255,255,.1) 30%,rgba(255,255,255,0) 100%);
  }
  @widgetstockcolor: #806d36;
  @widgetsalescolor: #7fad10;

  @import "../../shared.less";
  @import "./warehouseLayout1.less";
}

</style>

<style lang="less">
.warehouse.layout1.color2 {
  /* Warehouse common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/warehouse/containerbg.jpg);
  @tabactivefontcolor: #fff;


  @maincontentcolor: #ffffff;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }

  .fullback() {
    background-image: @bgimage;
    background-repeat:repeat;
    background-position:center 0rem;
    background-size:30rem 30rem;
    height:45.9rem;
  }
  /* Warehouse color 2 */
  @shoptitlecolor: #a60000;
  @logoborder: 0.5rem solid #a60000;
  @shopdesccolor:#a60000;
  @homemsgcolor:#7f0000;
  @welcomecolor: #a60000;
  @welcomeshadow: none;
  @activetabcolor: #1d4091;
  @navbgcolor: #2e55b0;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @bgimage: url(/images/shop/warehouse/warehouse2bg.jpg);
  @tabfontcolor: #ff7c7c;
  @lightsbg: url(/images/shop/warehouse/warehouse-lights2.png);
  .bggradient() {
    background: -moz-linear-gradient(top,  rgba(0,0,0,.2) 20%, rgba(0,0,2505,.1) 50%, rgba(0,0,0,0) 100%);
    background: linear-gradient(to bottom,  rgba(0,0,0,.2) 20%,rgba(0,0,0,.1) 50%,rgba(0,0,0,0) 100%);
  }
  @widgetstockcolor: #806d36;
  @widgetsalescolor: #7fad10;

  @import "../../shared.less";
  @import "./warehouseLayout1.less";

}

</style>

<style lang="less">
.warehouse.layout2.color1 {
  /* Warehouse common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/warehouse/containerbg.jpg);
  @tabactivefontcolor: #fff;


  @maincontentcolor: #ffffff;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }

  .fullback() {
    background-image: @bgimage;
    background-repeat:repeat;
    background-position:center 0rem;
    background-size:30rem 30rem;
    height:45.9rem;
  }
   /* Warehouse color 1 */
  @shoptitlecolor: #d5731a;
  @shopshadow:0.3rem 0.4rem 0.1rem rgba(0,0,0,0.3);
  @logoborder: 0.5rem solid #d5731a;
  @shopdesccolor:#fff;
  @homemsgcolor:#7f0000;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @bgimage: url(/images/shop/warehouse/warehouse2floorbg.jpg);
  @bgimage2: url(/images/shop/warehouse/warehouse2-headerbg.png);
  @tabfontcolor: #d5731a;
  @railsbg: url(/images/shop/warehouse/warehouse2-siderails.png);
  @widgetstockcolor: #806d36;
  @widgetsalescolor: #7fad10;
  @welcomecolor: #d5731a;
  @contentcolor:#464646;
  @welcomeshadow: -.1rem -.1rem 0 rgba(0,0,0,.4);

  @import "../../shared.less";
  @import "./warehouseLayout2.less";

}

</style>

<style lang="less">
.warehouse.layout2.color2 {
  /* Warehouse common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/warehouse/containerbg.jpg);
  @tabactivefontcolor: #fff;


  @maincontentcolor: #ffffff;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }

  .fullback() {
    background-image: @bgimage;
    background-repeat:repeat;
    background-position:center 0rem;
    background-size:30rem 30rem;
    height:45.9rem;
  }
  /* Warehouse color 2 */
  @shoptitlecolor: #4d436b;
  @shopshadow:0.2rem 0.3rem 0.1rem rgba(0,0,0,0.2);
  @logoborder: 0.5rem solid #4d436b;
  @shopdesccolor:#4d436b;
  @homemsgcolor:#144a68;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @bgimage: url(/images/shop/warehouse/warehouse2floorbg.jpg);
  @bgimage2: url(/images/shop/warehouse/warehouse2-headerbg2.png);
  @tabfontcolor: #a994eb;
  @railsbg: url(/images/shop/warehouse/warehouse2-siderails.png);
  @widgetstockcolor: #806d36;
  @widgetsalescolor: #7fad10;
  @welcomecolor: #4d436b;
  @contentcolor:#464646;
  @welcomeshadow: -.1rem -.1rem 0 rgba(0,0,0,.4);

  @import "../../shared.less";
  @import "./warehouseLayout2.less";
}

</style>